# Had to be made archful for 32-bit vulkan drivers
%define debug_package %{nil}

%define rdnsname net.lutris.Lutris

Name:           lutris
Version:        0.5.17
Release:        %mkrel 1
Summary:        Install and play any video game easily
Group:          Games/Other
License:        GPLv3+
URL:            https://lutris.net
Source0:        https://lutris.net/releases/%{name}_%{version}.tar.xz

# https://github.com/lutris/lutris/issues/3282
Patch0:         0001-status_icon-Use-AyatanaAppIndicator3-continuation-fo.patch

Patch1:         0001-webconnect_dialog-Only-use-WebKit2-4.1.patch

BuildRequires:  meson
BuildRequires:  gettext
BuildRequires:  python3-devel
BuildRequires:  python3-gobject3
BuildRequires:  python3-setuptools

# See https://github.com/lutris/lutris/blob/master/INSTALL.rs
# Validate that generated python3dist and typelib deps match the above.
# Those don't seem to be auto-generated.
Requires:       python3dist(distro)
Requires:       python3dist(lxml)
Requires:       python3dist(pillow)
Requires:       python3dist(setproctitle)

Requires:       xrandr

Recommends:     cabextract
Recommends:     curl
Recommends:     fluid-soundfont-gs
Recommends:     p7zip
Recommends:     psmisc

Recommends:     %{_lib}mesagl1
Recommends:     %{_lib}mesavulkan-drivers
Recommends:     %{_lib}vulkan-loader1
%ifarch x86_64
Recommends:     libmesagl1
Recommends:     libmesavulkan-drivers
Recommends:     libvulkan-loader1
%endif

%description
Lutris is a gaming platform for GNU/Linux. Its goal is to make
gaming on Linux as easy as possible by taking care of installing
and setting up the game for the user. The only thing you have to
do is play the game. It aims to support every game that is playable
on Linux.

%prep
%autosetup -p1 -n %{name}

# drop precompiled pycache
rm -rf $(find . -name "__pycache__" -type d -print)

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%meson -Dpython.bytecompile=-1
%meson_build

%install
%pyproject_install
%pyproject_save_files lutris

%meson_install

%find_lang %{name}

# Should not be needed, but it seems installing 32-bit libraries does not
# trigger it on x86_64
%post -p /sbin/ldconfig

%files -f %{name}.lang -f %{pyproject_files}
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{rdnsname}.desktop
%{_metainfodir}/%{rdnsname}.metainfo.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_mandir}/man1/%{name}.1.*

%pycached %{python3_sitelib}/lutris/optional_settings.py


%changelog
* Fri Apr 19 2024 daviddavid <daviddavid> 0.5.17-1.mga10
+ Revision: 2059527
- new version: 0.5.17
- add patch to only use typelib WebKit2 4.1

* Tue Feb 06 2024 daviddavid <daviddavid> 0.5.16-1.mga10
+ Revision: 2037834
- new version: 0.5.16
- rebuild for py3.12
- switch to pyproject

* Thu Feb 09 2023 daviddavid <daviddavid> 0.5.12-1.mga9
+ Revision: 1939554
- new version: 0.5.12

* Thu Aug 25 2022 akien <akien> 0.5.11-1.mga9
+ Revision: 1880411
- Version 0.5.11

* Thu May 26 2022 akien <akien> 0.5.10.1-1.mga9
+ Revision: 1860170
- Version 0.5.10.1

* Mon Apr 04 2022 akien <akien> 0.5.10-1.mga9
+ Revision: 1843674
- Version 0.5.10

* Thu Mar 31 2022 umeabot <umeabot> 0.5.9.1-2.mga9
+ Revision: 1836364
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 akien <akien> 0.5.9.1-1.mga9
+ Revision: 1779099
- Version 0.5.9.1

* Mon Jul 05 2021 akien <akien> 0.5.8.4-1.mga9
+ Revision: 1734765
- Version 0.5.8.4

* Tue Apr 20 2021 daviddavid <daviddavid> 0.5.8.3-3.mga9
+ Revision: 1717622
- rebuild for python 3.9

* Sun Feb 14 2021 akien <akien> 0.5.8.3-2.mga8
+ Revision: 1675342
- Add missing requires on python3-lxml (mga#28355)

* Tue Jan 26 2021 akien <akien> 0.5.8.3-1.mga8
+ Revision: 1673406
- Version 0.5.8.3

* Mon Dec 07 2020 akien <akien> 0.5.8.1-1.mga8
+ Revision: 1654041
- Version 0.5.8.1
- Patch to use file-magic, fixes mga#27619

* Sun Nov 15 2020 akien <akien> 0.5.8-1.mga8
+ Revision: 1646361
- Version 0.5.8

* Fri Nov 06 2020 akien <akien> 0.5.7.1-1.mga8
+ Revision: 1643076
- Version 0.5.7.1

* Thu Aug 06 2020 wally <wally> 0.5.7-2.mga8
+ Revision: 1611498
- port to Ayatana AppIndicator

* Tue Jul 14 2020 akien <akien> 0.5.7-1.mga8
+ Revision: 1605867
- Version 0.5.7
- Update requires and recommends based on upstream instructions
- Version 0.5.5

* Tue Feb 18 2020 umeabot <umeabot> 0.5.4-2.mga8
+ Revision: 1538905
- Mageia 8 Mass Rebuild

* Thu Nov 28 2019 akien <akien> 0.5.4-1.mga8
+ Revision: 1463317
- Version 0.5.4
- Version 0.5.3

* Tue Sep 17 2019 daviddavid <daviddavid> 0.5.2.1-3.mga8
+ Revision: 1442779
- rebuild for python3.8

* Thu Apr 18 2019 akien <akien> 0.5.2.1-2.mga7
+ Revision: 1393191
- Require cabextract

* Thu Apr 18 2019 akien <akien> 0.5.2.1-1.mga7
+ Revision: 1393170
- Version 0.5.2.1
- Made archful and recommends 32 and 64-bit vulkan libraries
- Trigger ldconfig manually as filetriggers seem not to run when installing 32-bit libs on 64-bit

* Tue Apr 09 2019 akien <akien> 0.5.2-1.mga7
+ Revision: 1387488
- Version 0.5.2

* Fri Apr 05 2019 daviddavid <daviddavid> 0.5.1.2-2.mga7
+ Revision: 1385854
- add missing dependency on python3-pillow (mga#24622)

* Mon Mar 25 2019 akien <akien> 0.5.1.2-1.mga7
+ Revision: 1380211
- Version 0.5.1.2

* Thu Feb 07 2019 akien <akien> 0.5.0.1-1.mga7
+ Revision: 1363833
- Version 0.5.0.1

* Fri Jan 11 2019 daviddavid <daviddavid> 0.4.23-3.mga7
+ Revision: 1355002
- rebuild for new Python 3.7

* Wed Jan 02 2019 akien <akien> 0.4.23-2.mga7
+ Revision: 1348694
- Fix non printable character inducing bogus Requires, thanks joeghi

* Wed Jan 02 2019 akien <akien> 0.4.23-1.mga7
+ Revision: 1348683
- Version 0.4.23
- Version 0.4.22

* Sun Oct 21 2018 akien <akien> 0.4.21-1.mga7
+ Revision: 1323427
- Version 0.4.21

* Tue Sep 25 2018 akien <akien> 0.4.20-1.mga7
+ Revision: 1304817
- Version 0.4.20

* Thu Sep 20 2018 umeabot <umeabot> 0.4.18-2.mga7
+ Revision: 1279240
- Mageia 7 Mass Rebuild

* Fri May 25 2018 akien <akien> 0.4.18-1.mga7
+ Revision: 1232143
- Version 0.4.18

* Thu May 24 2018 akien <akien> 0.4.17-1.mga7
+ Revision: 1232031
- Version 0.4.17

* Mon May 21 2018 akien <akien> 0.4.16-1.mga7
+ Revision: 1231122
- Version 0.4.16

* Fri Dec 22 2017 akien <akien> 0.4.14-1.mga7
+ Revision: 1184064
- Version 0.4.14

* Sat Aug 05 2017 pterjan <pterjan> 0.4.13-2.mga7
+ Revision: 1135267
- Rebuild for python 3.6

* Thu Jul 27 2017 akien <akien> 0.4.13-1.mga7
+ Revision: 1131535
- Version 0.4.13

* Fri Jun 16 2017 akien <akien> 0.4.12-1.mga6
+ Revision: 1107814
- Version 0.4.12

* Sat Jun 03 2017 akien <akien> 0.4.11.1-1.mga6
+ Revision: 1105900
- Version 0.4.11.1

* Tue May 16 2017 akien <akien> 0.4.10-1.mga6
+ Revision: 1101867
- Version 0.4.10

* Fri May 05 2017 akien <akien> 0.4.9-1.mga6
+ Revision: 1099181
- Version 0.4.9

* Sun Apr 23 2017 akien <akien> 0.4.8-1.mga6
+ Revision: 1097173
- Version 0.4.8

* Sun Apr 16 2017 akien <akien> 0.4.7.1-1.mga6
+ Revision: 1096593
- Version 0.4.7.1
- Version 0.4.7

* Wed Mar 22 2017 akien <akien> 0.4.6-1.mga6
+ Revision: 1094251
- Version 0.4.6

* Wed Mar 08 2017 akien <akien> 0.4.5-1.mga6
+ Revision: 1090197
- Version 0.4.5

* Sun Dec 18 2016 akien <akien> 0.4.4.1-1.mga6
+ Revision: 1075935
- Version 0.4.4.1

* Tue Nov 29 2016 akien <akien> 0.4.3-1.mga6
+ Revision: 1071026
- Version 0.4.3

* Wed Nov 02 2016 akien <akien> 0.4.2-1.mga6
+ Revision: 1064718
- Version 0.4.2

* Tue Oct 25 2016 akien <akien> 0.4.1-1.mga6
+ Revision: 1063514
- Version 0.4.1

* Sat Oct 15 2016 akien <akien> 0.4.0-1.mga6
+ Revision: 1060843
- Version 0.4.0
- Switch to python3 build

* Thu Aug 11 2016 akien <akien> 0.3.8-1.mga6
+ Revision: 1045945
- Require python-evdev for gamepad features
- Version 0.3.8

* Sat May 21 2016 akien <akien> 0.3.7.5-4.mga6
+ Revision: 1017407
- Upstream patch to silence stderr output

* Tue May 10 2016 daviddavid <daviddavid> 0.3.7.5-3.mga6
+ Revision: 1011983
- add missing requires on python-dbus (fixes mga#18410)

* Sat Apr 23 2016 akien <akien> 0.3.7.5-2.mga6
+ Revision: 1005506
- Fix window size reset to small values

* Mon Mar 07 2016 akien <akien> 0.3.7.5-1.mga6
+ Revision: 987234
- Version 0.3.7.5

* Sun Feb 28 2016 akien <akien> 0.3.7.3-1.mga6
+ Revision: 980438
- Version 0.3.7.3

* Tue Jan 05 2016 akien <akien> 0.3.7.2-1.mga6
+ Revision: 919894
- Version 0.3.7.2
- Drop no longer needed deps

* Sat Dec 12 2015 akien <akien> 0.3.7-1.mga6
+ Revision: 909684
- Version 0.3.7

* Wed Nov 26 2014 akien <akien> 0.3.6.3-1.mga5
+ Revision: 799337
- Add missing xrandr Requires
- Version 0.3.6.3

* Wed Nov 12 2014 akien <akien> 0.3.6.2-1.mga5
+ Revision: 796654
- Version 0.3.6.2

* Tue Nov 11 2014 akien <akien> 0.3.5-5.mga5
+ Revision: 796471
- Add a missing gvfs Requires as found out upstream on git#110

* Mon Nov 10 2014 akien <akien> 0.3.5-4.mga5
+ Revision: 796175
- Add dependency on glib-networking (fix upstream git#110)

* Wed Oct 15 2014 umeabot <umeabot> 0.3.5-3.mga5
+ Revision: 746065
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.3.5-2.mga5
+ Revision: 727001
- rebuild for missing pythoneggs deps

* Tue Sep 23 2014 akien <akien> 0.3.5-1.mga5
+ Revision: 719250
- imported package lutris


* Fri Sep 12 2014 Mathieu Comandon <strycore@gmail.com> - 0.3.5-1
- Bump version to 0.3.5

* Thu Aug 14 2014 Travis Nickles <nickles.travis@gmail.com> - 0.3.4-3
- Edited Requires to include pygobject3.

* Wed Jun 04 2014 Travis Nickles <nickles.travis@gmail.com> - 0.3.4-2
- Changed build and install step based on template generated by
  rpmdev-newspec.
- Added Requires.
- Ensure package can be built using mock.

* Tue Jun 03 2014 Travis Nickles <nickles.travis@gmail.com> - 0.3.4-1
- Initial version of the package
